ContextualizedError

Struct ContextualizedError 

pub struct ContextualizedError<I> {
    pub input: I,
    pub char: Option<char>,
    pub error: Option<Error>,
    pub context: Vec<(I, &'static str)>,
}
A nom-compatible error type that captures relevant information for the SGML parser.

Fields

input: I

The remaining input when the error occurred.

char: Option<char>

Was a certain character expected?

error: Option<Error>context: Vec<(I, &'static str)>

The collected context.

Implementations

Source

impl<I: Deref<Target = str>> ContextualizedError<I>

pub fn describe(&self, input: &I) -> String

Returns a string describing this error.

pub fn describe_to<W: Write>(&self, input: &I, f: W) -> Result

Writes the detailed description of this error to the given output.